==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-canvas-new.dart <==
/*
Description:
The canvas widget allows users to write on the screen by replicating the pattern made by the finger on the screen.
Users can choose the colour and the thickness of the line via the drop-downs available.
The drop downs are parameterised and accept a range of parameters such as colour, text size, text colour etc

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-canvas-new.dart';


Usage:
-Creating the object for the canvas

    CustomPainterParameters painterParameters = new CustomPainterParameters();
    CustomCanvasOptionsParameters dropParam = new CustomCanvasOptionsParameters(widthThickness: 110,
        widthColor: 110,
        bgColorColour: Colors.grey,
      bgColorThickness: Colors.grey,
      textColorColour: Colors.black,
      textColorThickness: Colors.black,
    );


-Object call for the widget
          body: Center(child: CustomSignatureNew(painterParameters,dropParam))

    Author:
    Karan Arora
*/


import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/custom-dropdownButton.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';



class CustomSignatureNew extends StatefulWidget {
  final CustomPainterParameters painterParameters;
  final CustomCanvasOptionsParameters dropDownParameters;
  CustomSignatureNew(this.painterParameters,this.dropDownParameters);

  @override
  _HomePageState createState() => new _HomePageState(this.painterParameters,this.dropDownParameters);
}

class _HomePageState extends State<CustomSignatureNew> {

  CustomPainterParameters painterParameters;
  CustomCanvasOptionsParameters dropDownParameters;
  _HomePageState(this.painterParameters,this.dropDownParameters);
  List<Offset> pointsNew = <Offset>[];

  Color colour;
  callbackColor(int i, String string){

      if(string=="blue"){
        colour= Colors.blue;
      }
      else if(string=="red"){
        colour= Colors.red;
      }
      else if(string=="yellow"){
        colour= Colors.yellow;
      }
      else if(string=="black"){
        colour= Colors.black;
      }
      else if(string=="orange"){
        colour= Colors.orange;
      }
      else if(string=="green"){
        colour= Colors.green;
      }
      else if(string=="purple"){
        colour= Colors.purple;
      }
  }

  double width;
  callbackWidth(int i, String string1){

      width=double.parse(string1);

  }

  Widget build(BuildContext context) {
    DropDownParameters dropdownobject1=new DropDownParameters(itemsList: ["blue","yellow","red","black","orange","green","purple"],
        hintText: 'Color',
        width: (dropDownParameters.widthColor != null) ? dropDownParameters.widthColor : cons.heightHundred,
        height: (dropDownParameters.heightColor != null) ? dropDownParameters.heightColor : cons.heightThirty,
        fontSize: (dropDownParameters.fontSizeColour != null) ? dropDownParameters.fontSizeColour : cons.heightTen+cons.heightFive,
        textColor: (dropDownParameters.textColorColour != null) ? dropDownParameters.textColorColour : Theme.of(context).textSelectionColor,
        fillColor: (dropDownParameters.bgColorColour != null) ? dropDownParameters.bgColorColour : Theme.of(context).buttonColor,
        fontWeight: (dropDownParameters.fontWeightColour != null) ? dropDownParameters.fontWeightColour : FontWeight.normal,
        fontFamily: (dropDownParameters.fontFamilyColour != null) ? dropDownParameters.fontFamilyColour : cons.textStyle,
    );
    DropDownParameters dropdownobject2=new DropDownParameters(itemsList: ["1.0","2.0","3.0","4.0","5.0","7.0","10.0"],
        hintText: 'Width',
      width: (dropDownParameters.widthThickness != null) ? dropDownParameters.widthThickness : cons.heightHundred,
      height: (dropDownParameters.heightThickness != null) ? dropDownParameters.heightThickness : cons.heightThirty,
      fontSize: (dropDownParameters.fontSizeThickness != null) ? dropDownParameters.fontSizeThickness : cons.heightTen+cons.heightFive,
      textColor: (dropDownParameters.textColorThickness != null) ? dropDownParameters.textColorThickness : Theme.of(context).textSelectionColor,
      fillColor: (dropDownParameters.bgColorThickness != null) ? dropDownParameters.bgColorThickness : Theme.of(context).buttonColor,
      fontWeight: (dropDownParameters.fontWeightThickness != null) ? dropDownParameters.fontWeightThickness : FontWeight.normal,
      fontFamily: (dropDownParameters.fontFamilyThickness != null) ? dropDownParameters.fontFamilyThickness : cons.textStyle,
        );

    return Column(
        children: <Widget>[

          Container(
            decoration: BoxDecoration(
              border: Border.all(width: (dropDownParameters.borderWidth != null) ? dropDownParameters.borderWidth : cons.heightOne,
                  color: (dropDownParameters.borderColor != null) ? dropDownParameters.borderColor : Theme.of(context).primaryColorDark),
            ),
/*            height: ,
            width: ,*/

            child: new GestureDetector(
              onPanUpdate: (DragUpdateDetails details) {
                setState(() {
                  RenderBox object = context.findRenderObject();
                  Offset localPosition =
                  object.globalToLocal(details.globalPosition);
                  pointsNew = new List.from(pointsNew)..add(localPosition);
                });
              },
              onPanEnd: (DragEndDetails details) => pointsNew.add(null),
              child: new CustomPaint(
                painter: new Signature(points: pointsNew, painterParameters: painterParameters, colour: colour, width: width),
                size: Size.square(MediaQuery. of(context). size. width),
              ),
            ),
          ),
          SizedBox(height: cons.heightFifty,),
          Row(
            children: <Widget>[
              SizedBox(width: 20,),
              CustomDropdownButton(dropdownobject1,callbackColor),
              SizedBox(width: 20,),
              CustomDropdownButton(dropdownobject2,callbackWidth),
              SizedBox(width: 20,),
              FlatButton(child: Icon(Icons.delete),onPressed: () => pointsNew.clear(),
              color: (dropDownParameters.btnColor != null) ? dropDownParameters.btnColor : Theme.of(context).primaryColorDark,
              ),
            ],
          ),
        ],
      );
  }
}

class Signature extends CustomPainter {
  List<Offset> points;
  CustomPainterParameters painterParameters;
  Color colour;
  double width;


  Signature({this.points, this.painterParameters, this.colour,this.width});

  @override
  void paint(Canvas canvas, Size size) {
    Paint paint = new Paint()
      ..color = (colour == null) ? Colors.black : colour
      ..strokeWidth = (width == null) ? 2.0 : width;

    for (int i = 0; i < points.length - 1; i++) {
      if (points[i] != null && points[i + 1] != null) {
        canvas.drawLine(points[i], points[i + 1], paint);
      }
    }
  }


//  @override
  bool shouldRepaint(Signature oldDelegate) => oldDelegate.points != points;
}

==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom-canvas-new.dart <==
/*
Description:
The canvas widget allows users to write on the screen by replicating the pattern made by the finger on the screen.
Users can choose the colour and the thickness of the line via the drop-downs available.
The drop downs are parameterised and accept a range of parameters such as colour, text size, text colour etc

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-canvas-new.dart';


Usage:
-Creating the object for the canvas

    CustomPainterParameters painterParameters = new CustomPainterParameters();
    CustomCanvasOptionsParameters dropParam = new CustomCanvasOptionsParameters(widthThickness: 110,
        widthColor: 110,
        bgColorColour: Colors.grey,
      bgColorThickness: Colors.grey,
      textColorColour: Colors.black,
      textColorThickness: Colors.black,
    );


-Object call for the widget
          body: Center(child: CustomSignatureNew(painterParameters,dropParam))

    Author:
    Karan Arora
*/


import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/custom-dropdownButton.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as cons;
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';



class CustomSignatureNew extends StatefulWidget {
  final CustomPainterParameters painterParameters;
  final CustomCanvasOptionsParameters dropDownParameters;
  CustomSignatureNew(this.painterParameters,this.dropDownParameters);

  @override
  _HomePageState createState() => new _HomePageState(this.painterParameters,this.dropDownParameters);
}

class _HomePageState extends State<CustomSignatureNew> {

  CustomPainterParameters painterParameters;
  CustomCanvasOptionsParameters dropDownParameters;
  _HomePageState(this.painterParameters,this.dropDownParameters);
  List<Offset> pointsNew = <Offset>[];

  Color colour;
  callbackColor(int i, String string){

      if(string=="blue"){
        colour= Colors.blue;
      }
      else if(string=="red"){
        colour= Colors.red;
      }
      else if(string=="yellow"){
        colour= Colors.yellow;
      }
      else if(string=="black"){
        colour= Colors.black;
      }
      else if(string=="orange"){
        colour= Colors.orange;
      }
      else if(string=="green"){
        colour= Colors.green;
      }
      else if(string=="purple"){
        colour= Colors.purple;
      }
  }

  double width;
  callbackWidth(int i, String string1){

      width=double.parse(string1);

  }

  Widget build(BuildContext context) {
    DropDownParameters dropdownobject1=new DropDownParameters(itemsList: ["blue","yellow","red","black","orange","green","purple"],
        hintText: 'Color',
        width: (dropDownParameters.widthColor != null) ? dropDownParameters.widthColor : cons.heightHundred,
        height: (dropDownParameters.heightColor != null) ? dropDownParameters.heightColor : cons.heightThirty,
        fontSize: (dropDownParameters.fontSizeColour != null) ? dropDownParameters.fontSizeColour : cons.heightTen+cons.heightFive,
        textColor: (dropDownParameters.textColorColour != null) ? dropDownParameters.textColorColour : Theme.of(context).textSelectionColor,
        fillColor: (dropDownParameters.bgColorColour != null) ? dropDownParameters.bgColorColour : Theme.of(context).buttonColor,
        fontWeight: (dropDownParameters.fontWeightColour != null) ? dropDownParameters.fontWeightColour : FontWeight.normal,
        fontFamily: (dropDownParameters.fontFamilyColour != null) ? dropDownParameters.fontFamilyColour : cons.textStyle,
    );
    DropDownParameters dropdownobject2=new DropDownParameters(itemsList: ["1.0","2.0","3.0","4.0","5.0","7.0","10.0"],
        hintText: 'Width',
      width: (dropDownParameters.widthThickness != null) ? dropDownParameters.widthThickness : cons.heightHundred,
      height: (dropDownParameters.heightThickness != null) ? dropDownParameters.heightThickness : cons.heightThirty,
      fontSize: (dropDownParameters.fontSizeThickness != null) ? dropDownParameters.fontSizeThickness : cons.heightTen+cons.heightFive,
      textColor: (dropDownParameters.textColorThickness != null) ? dropDownParameters.textColorThickness : Theme.of(context).textSelectionColor,
      fillColor: (dropDownParameters.bgColorThickness != null) ? dropDownParameters.bgColorThickness : Theme.of(context).buttonColor,
      fontWeight: (dropDownParameters.fontWeightThickness != null) ? dropDownParameters.fontWeightThickness : FontWeight.normal,
      fontFamily: (dropDownParameters.fontFamilyThickness != null) ? dropDownParameters.fontFamilyThickness : cons.textStyle,
        );

    return Column(
        children: <Widget>[

          Container(
            decoration: BoxDecoration(
              border: Border.all(width: (dropDownParameters.borderWidth != null) ? dropDownParameters.borderWidth : cons.heightOne,
                  color: (dropDownParameters.borderColor != null) ? dropDownParameters.borderColor : Theme.of(context).primaryColorDark),
            ),
/*            height: ,
            width: ,*/

            child: new GestureDetector(
              onPanUpdate: (DragUpdateDetails details) {
                setState(() {
                  RenderBox object = context.findRenderObject();
                  Offset localPosition =
                  object.globalToLocal(details.globalPosition);
                  pointsNew = new List.from(pointsNew)..add(localPosition);
                });
              },
              onPanEnd: (DragEndDetails details) => pointsNew.add(null),
              child: new CustomPaint(
                painter: new Signature(points: pointsNew, painterParameters: painterParameters, colour: colour, width: width),
                size: Size.square(MediaQuery. of(context). size. width),
              ),
            ),
          ),
          SizedBox(height: cons.heightFifty,),
          Row(
            children: <Widget>[
              SizedBox(width: 20,),
              CustomDropdownButton(dropdownobject1,callbackColor),
              SizedBox(width: 20,),
              CustomDropdownButton(dropdownobject2,callbackWidth),
              SizedBox(width: 20,),
              FlatButton(child: Icon(Icons.delete),onPressed: () => pointsNew.clear(),
              color: (dropDownParameters.btnColor != null) ? dropDownParameters.btnColor : Theme.of(context).primaryColorDark,
              ),
            ],
          ),
        ],
      );
  }
}

class Signature extends CustomPainter {
  List<Offset> points;
  CustomPainterParameters painterParameters;
  Color colour;
  double width;


  Signature({this.points, this.painterParameters, this.colour,this.width});

  @override
  void paint(Canvas canvas, Size size) {
    Paint paint = new Paint()
      ..color = (colour == null) ? Colors.black : colour
      ..strokeWidth = (width == null) ? 2.0 : width;

    for (int i = 0; i < points.length - 1; i++) {
      if (points[i] != null && points[i + 1] != null) {
        canvas.drawLine(points[i], points[i + 1], paint);
      }
    }
  }


//  @override
  bool shouldRepaint(Signature oldDelegate) => oldDelegate.points != points;
}
